@@ -2,7 +2,7 @@
 
 # Generic tasks
 from .basics import dump, glob, log, noop, sync, walk, write
-from .files import rename_replace, strip_dirs
+from .files import directory, rename_replace, strip_dirs
 from .filters import exclude, match
 from .text import concat, contents_replace, footer, header, regex
 
@@ -13,5 +13,6 @@ from .gzip import gzip
 from .html import minify_html
 from .javascript import coffee, traceur, uglify
 from .markdown import markdown
+from .png import optipng, pngquant
 from .textile import textile
 from .web import cachebust
