@@ -2,6 +2,7 @@ from pathlib import Path
 
 from ..core import Task
 
+
 class directory(Task):
     def __init__(self, dirname):
         self.dirname = Path(dirname)
@@ -11,14 +12,31 @@ class directory(Task):
             yield self.dirname / t, c, m
 
 
-class rename_replace(Task):
-    def __init__(self, substring, replacement):
-        self.substring = substring
-        self.replacement = replacement
+class modify_path(Task):
+    """Generic purpose task for changing file paths."""
+    def __init__(self, func):
+        self.func = func
 
     def process(self, inputs):
         for t, c, m in inputs:
-            t2 = Path(str(t).replace(self.substring, self.replacement))
+            yield Path(self.func(t)), c, m
+
+
+def rename_replace(substring, replacement):
+    func = lambda path: str(path).replace(substring, replacement)
+    return modify_path(func)
+
+
+class relative_to(Task):
+    def __init__(self, base):
+        self.base = base
+
+    def process(self, inputs):
+        for t, c, m in inputs:
+            try:
+                t2 = t.relative_to(self.base)
+            except ValueError:
+                continue  # drop file
             yield t2, c, m
 
 
