@@ -13,8 +13,18 @@ class markdown(Task):
             raise ImportError('To use markdown(), run: pip install markdown') from e
 
         from markdown.extensions.codehilite import CodeHiliteExtension
-        hilite = CodeHiliteExtension(css_class='foo')
-        self.convert = partial(markdown_fn, extensions=['markdown.extensions.fenced_code', hilite])
+        hilite = CodeHiliteExtension(guess_lang=False)
+
+        self.convert = partial(markdown_fn, extensions=[
+            # 'markdown.extensions.codehilite',
+            hilite,
+            'markdown.extensions.fenced_code',
+            'markdown.extensions.attr_list',
+            'markdown.extensions.sane_lists',
+            # 'markdown.extensions.tables',
+            'markdown.extensions.headerid',
+            'markdown.extensions.def_list',
+        ])
 
     def lazy_convert(self, contents):
         yield self.convert(b''.join(contents).decode('utf-8')).encode('utf-8')
