@@ -17,12 +17,12 @@ class cachebust(Task):
 
     def process(self, inputs):
         mapping = {}
-        for t, c in inputs:
+        for t, c, m in inputs:
             c1, c2 = tee(c)
             h = getattr(hashlib, self.algorithm)()
             for chunk in c1:
                 h.update(chunk)
             t2 = t.stem + '-' + h.hexdigest()[:self.length] + t.suffix
             mapping[str(t)] = str(t2)
-            yield t2, c2
-        yield 'manifest.json', [json.dumps(mapping).encode('utf-8')]
+            yield t2, c2, m
+        yield 'manifest.json', [json.dumps(mapping).encode('utf-8')], {}
